<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko" sourcelanguage="en">
<context>
    <name>AddFxContextMenu</name>
    <message>
        <source>Insert FX</source>
        <translation>Fx 삽입</translation>
    </message>
    <message>
        <source>Add FX</source>
        <translation>Fx 추가</translation>
    </message>
    <message>
        <source>Replace FX</source>
        <translation>Fx 교체</translation>
    </message>
    <message>
        <source>Insert </source>
        <translation>삽입</translation>
    </message>
    <message>
        <source>Add </source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Replace </source>
        <translation>교체</translation>
    </message>
</context>
<context>
    <name>AddWordButton</name>
    <message>
        <source>Character</source>
        <translation>캐릭터</translation>
    </message>
    <message>
        <source>Part</source>
        <translation>부분</translation>
    </message>
    <message>
        <source>Suffix</source>
        <translation>접미사</translation>
    </message>
    <message>
        <source>New</source>
        <translation>새로운</translation>
    </message>
    <message>
        <source>Add New Word for %1</source>
        <translation>%1에 대한 새 단어 추가</translation>
    </message>
</context>
<context>
    <name>AdjustPaletteDialog</name>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>이 팔레트에 현재 레벨 조정</translation>
    </message>
    <message>
        <source>Tolerance</source>
        <translation>공차</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>CameraPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>중심 재설정(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>활성화(&amp;A)</translation>
    </message>
</context>
<context>
    <name>CameraSettingsWidget</name>
    <message>
        <source>DPI</source>
        <translation></translation>
    </message>
    <message>
        <source>Pixels</source>
        <translation>픽셀</translation>
    </message>
    <message>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <source>Use Current Level Settings</source>
        <translation>현재 레벨 설정 사용</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Force Squared Pixel</source>
        <translation>포스 제곱 픽셀</translation>
    </message>
    <message>
        <source>A/R</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;사용자 정의&gt;</translation>
    </message>
    <message>
        <source>Bad camera preset</source>
        <translation>잘못된 카메라 사전설정</translation>
    </message>
    <message>
        <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset. 
Possibly the preset file has been corrupted</source>
        <translation>%1은 잘 형성된 카메라 사전 설정으로 보임. 
사전 설정 파일이 손상되었을 수 있음</translation>
    </message>
    <message>
        <source>Preset name</source>
        <translation>사전설정 이름</translation>
    </message>
    <message>
        <source>Enter the name for %1</source>
        <translation>%1의 이름을 입력 하세요</translation>
    </message>
    <message>
        <source>Error : Preset Name is Invalid</source>
        <translation>오류 : 사전 설정 이름이 잘못됨</translation>
    </message>
    <message>
        <source>The preset name must not use &apos;,&apos;(comma).</source>
        <translation>사전 설정 이름은 &apos;,&apos;(쉼표)를 사용해서는 안됨.</translation>
    </message>
    <message>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>inch</source>
        <translation>inch</translation>
    </message>
    <message>
        <source>field</source>
        <translation>field</translation>
    </message>
    <message>
        <source>pixel</source>
        <translation>픽셀</translation>
    </message>
</context>
<context>
    <name>ChannelHisto</name>
    <message>
        <source>Red</source>
        <translation>빨강</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>녹색</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>파랑</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>알파</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
</context>
<context>
    <name>CleanupCameraSettingsWidget</name>
    <message>
        <source>Y</source>
        <translation></translation>
    </message>
    <message>
        <source>X</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ColorChannelControl</name>
    <message>
        <source>H</source>
        <translation>수평</translation>
    </message>
</context>
<context>
    <name>ColumnPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>중심 재설정(&amp;R)</translation>
    </message>
</context>
<context>
    <name>ComboHistoRGBLabel</name>
    <message>
        <source>R:%1 G:%2 B:%3</source>
        <translation>R:%1 G:%2 B:%3</translation>
    </message>
    <message>
        <source> A:%1</source>
        <translation> A:%1</translation>
    </message>
    <message>
        <source>A:%1</source>
        <translation>A:%1</translation>
    </message>
</context>
<context>
    <name>ComboHistogram</name>
    <message>
        <source>Picked Color</source>
        <translation>선택한 색상</translation>
    </message>
    <message>
        <source>Average Color (Ctrl + Drag)</source>
        <translation>평균 색상(Ctrl + Drag)</translation>
    </message>
    <message>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <source>8bit (0-255)</source>
        <translation>8bit (0-255)</translation>
    </message>
    <message>
        <source>16bit (0-65535)</source>
        <translation>16bit (0-65535)</translation>
    </message>
    <message>
        <source>0.0-1.0</source>
        <translation>0.0-1.0</translation>
    </message>
</context>
<context>
    <name>DVGui</name>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>DVGui::CleanupColorField</name>
    <message>
        <source>Brightness:</source>
        <translation>밝기:</translation>
    </message>
    <message>
        <source>Contrast:</source>
        <translation>대비:</translation>
    </message>
    <message>
        <source>Color Thres</source>
        <translation>색상 값</translation>
    </message>
    <message>
        <source>White Thres</source>
        <translation>흰색 값</translation>
    </message>
    <message>
        <source>H Range</source>
        <translation>수평범위</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>선 폭</translation>
    </message>
</context>
<context>
    <name>DVGui::ColorField</name>
    <message>
        <source>R:</source>
        <translation></translation>
    </message>
    <message>
        <source>G:</source>
        <translation></translation>
    </message>
    <message>
        <source>B:</source>
        <translation></translation>
    </message>
    <message>
        <source>A:</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste Color</source>
        <translation>색상 붙여넣기</translation>
    </message>
    <message>
        <source>Paste Color of %1</source>
        <translation>%1의 색상 붙여넣기</translation>
    </message>
    <message>
        <source>Copy Color</source>
        <translation>색상 복사</translation>
    </message>
</context>
<context>
    <name>DVGui::DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation>볼드</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>이탤릭체</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation>왼쪽 정렬</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation>중심 정렬</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation>오른쪽 정렬</translation>
    </message>
</context>
<context>
    <name>DVGui::FileField</name>
    <message>
        <source>...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DVGui::HexColorNamesEditor</name>
    <message>
        <source>Hex Color Names Editor</source>
        <translation>16진수 색상 이름 편집기</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>선택 해제</translation>
    </message>
    <message>
        <source>Add Color</source>
        <translation>색상 추가</translation>
    </message>
    <message>
        <source>Delete Color</source>
        <translation>색상 삭제</translation>
    </message>
    <message>
        <source>User Defined Colors</source>
        <translation>정의된 색상</translation>
    </message>
    <message>
        <source>Default Main Colors</source>
        <translation>기본 메인 컬러</translation>
    </message>
    <message>
        <source>Enable Auto-Complete</source>
        <translation>자동 완성 사용</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>수입</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>수출</translation>
    </message>
    <message>
        <source>Open Color Names</source>
        <translation>색상 이름 열기</translation>
    </message>
    <message>
        <source>Text or XML (*.txt *.xml);;Text files (*.txt);;XML files (*.xml)</source>
        <translation>텍스트 또는 XML (*.txt *.xml);; 텍스트 파일 (*.txt);; XML 파일 (*.xml)</translation>
    </message>
    <message>
        <source>Hex Color Names Import</source>
        <translation>16진수 색상 이름 가져오기</translation>
    </message>
    <message>
        <source>Do you want to merge with existing entries?</source>
        <translation>기존 항목과 병합하시겠습니까?</translation>
    </message>
    <message>
        <source>Error importing color names XML</source>
        <translation>색상 이름 XML을 가져오는 중 오류 발생</translation>
    </message>
    <message>
        <source>Save Color Names</source>
        <translation>색상 이름 저장</translation>
    </message>
    <message>
        <source>XML files (*.xml);;Text files (*.txt)</source>
        <translation>XML 파일 (*.xml);; 텍스트 파일 (*.txt)</translation>
    </message>
    <message>
        <source>Error exporting color names XML</source>
        <translation>색 이름 XML 내보내기 오류</translation>
    </message>
</context>
<context>
    <name>DVGui::LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation>파일 이름에는 다음 문자 중 어느 것도 포함될 수 없음: /\:*?&quot;&lt;&gt;|.</translation>
    </message>
    <message>
        <source>A file name cannot contains any of the following characters: /\:*?&quot;&lt;&gt;|.</source>
        <translation>파일 이름에는 다음 문자 중 하나를 포함할 수 없습니다: /\:*?&lt;&gt;\.</translation>
    </message>
</context>
<context>
    <name>DVGui::ProgressDialog</name>
    <message>
        <source>OpenToonz</source>
        <translation>오픈툰즈</translation>
    </message>
</context>
<context>
    <name>DVGui::RadioButtonDialog</name>
    <message>
        <source>OpenToonz</source>
        <translation>오픈툰즈</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>현재</translation>
    </message>
</context>
<context>
    <name>DVGui::ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation>채널:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>범위:</translation>
    </message>
    <message>
        <source>Output:</source>
        <translation>출력:</translation>
    </message>
    <message>
        <source>Input:</source>
        <translation>입력 :</translation>
    </message>
</context>
<context>
    <name>DVGui::ValidatedChoiceDialog</name>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Apply to All</source>
        <translation>모두 적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation>볼드</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>이탤릭체</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation>왼쪽 정렬</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation>중심 정렬</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation>오른쪽 정렬</translation>
    </message>
</context>
<context>
    <name>EaseInOutSegmentPage</name>
    <message>
        <source>Ease In:</source>
        <translation>서서히 멈춤:</translation>
    </message>
    <message>
        <source>Ease Out:</source>
        <translation>서서히 시작:</translation>
    </message>
</context>
<context>
    <name>EasyInputArea</name>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>%1 is already registered</source>
        <translation>%1은 이미등록되어 있음</translation>
    </message>
</context>
<context>
    <name>FileSegmentPage</name>
    <message>
        <source>File Path:</source>
        <translation>파일 경로:</translation>
    </message>
    <message>
        <source>Column:</source>
        <translation>열:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>단위:</translation>
    </message>
</context>
<context>
    <name>FlipConsole</name>
    <message>
        <source> FPS </source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>스냅샷</translation>
    </message>
    <message>
        <source>Define Sub-camera</source>
        <translation>서브 카메라 정의</translation>
    </message>
    <message>
        <source>Define Loading Box</source>
        <translation>로딩 상자 정의</translation>
    </message>
    <message>
        <source>Use Loading Box</source>
        <translation>로딩 상자 사용</translation>
    </message>
    <message>
        <source>Background Colors</source>
        <translation>배경색</translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation>프레임 비율</translation>
    </message>
    <message>
        <source>Playback Controls</source>
        <translation>재생 제어</translation>
    </message>
    <message>
        <source>Color Channels</source>
        <translation>컬러 채널</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>키 설정</translation>
    </message>
    <message>
        <source>Histogram</source>
        <translation>히스토그램</translation>
    </message>
    <message>
        <source>Display Areas as Filled</source>
        <translation>채워진 영역 표시</translation>
    </message>
    <message>
        <source>&amp;Save Images</source>
        <translation>이미지 저장(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Snapshot</source>
        <translation>스냅샷(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Compare to Snapshot</source>
        <translation>스탭샷과 비교(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Define Sub-camera</source>
        <translation>서브 카메라 정의(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Define Loading Box</source>
        <translation>로딩 상자 정의(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Use Loading Box</source>
        <translation>로딩 상자 사용(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>흰색 배경(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>검은 배경(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>체크무늬 배경(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;First Frame</source>
        <translation>첫번째 프레임(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Previous Frame</source>
        <translation>이전 프레임(&amp;P)</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>중지</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>고리</translation>
    </message>
    <message>
        <source>&amp;Next frame</source>
        <translation>다음 프레임(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Last Frame</source>
        <translation>마지막 프레임(&amp;L)</translation>
    </message>
    <message>
        <source>Red Channel</source>
        <translation>레드 채널</translation>
    </message>
    <message>
        <source>Red Channel in Grayscale</source>
        <translation>그레이 스케일 적색 채널</translation>
    </message>
    <message>
        <source>Green Channel</source>
        <translation>녹색 채널</translation>
    </message>
    <message>
        <source>Green Channel in Grayscale</source>
        <translation>그레이 스케일 녹색 채널</translation>
    </message>
    <message>
        <source>Blue Channel</source>
        <translation>블루 채널</translation>
    </message>
    <message>
        <source>Blue Channel in Grayscale</source>
        <translation>그레이 스케일의 블루채널</translation>
    </message>
    <message>
        <source>Alpha Channel</source>
        <translation>알파 채널</translation>
    </message>
    <message>
        <source>&amp;Soundtrack </source>
        <translation>사운드 트랙(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Histogram</source>
        <translation>히스토그램(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Locator</source>
        <translation>로케이터(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Display Areas as Filled</source>
        <translation>채워진 영역 표시(&amp;D)</translation>
    </message>
    <message>
        <source> FPS	</source>
        <translation></translation>
    </message>
    <message>
        <source>Set the current frame</source>
        <translation>현재 프레임 설정</translation>
    </message>
    <message>
        <source>Drag to play the animation</source>
        <translation>애니메이션을 재생하려면 끌어서 놓으세요</translation>
    </message>
    <message>
        <source>Set the playback frame rate</source>
        <translation>재생 프레임 속도설정</translation>
    </message>
    <message>
        <source>Viewer Controls</source>
        <translation>뷰어 컨트롤</translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation>확대(&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation>축소(&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Flip Horizontally</source>
        <translation>수평으로 뒤집기(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Flip Vertically</source>
        <translation>수직으로 뒤집기(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Reset View</source>
        <translation>보기 재설정(&amp;R)</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>소리</translation>
    </message>
    <message>
        <source>Locator</source>
        <translation>로케이터</translation>
    </message>
    <message>
        <source>&amp;Next Frame</source>
        <translation>다음 프레임(&amp;N)</translation>
    </message>
    <message>
        <source>Gain Controls</source>
        <translation>게인 컨트롤</translation>
    </message>
    <message>
        <source>&amp;Reduce gain 1/2 stop (divide by sqrt(2))</source>
        <translation>&amp;이득 1/2 스톱 감소(제곱(2)으로 나누기)</translation>
    </message>
    <message>
        <source>Toggle gain between 1 and the previous setting.
Gain is shown as an f-stop and the &quot;neutral&quot; or 1.0 gain f-stop is f/8.</source>
        <translation>게임을 1과 이전 설정 사이에서 전환합니다.
게인은 F-스톱으로 표시되며 &quot;중립&quot; 또는 1.0 게인 F-스톱은 F.8입니다.</translation>
    </message>
    <message>
        <source>&amp;Increase gain 1/2 stop (multiply by sqrt(2))</source>
        <translation>&amp;증가 게인 1/2스톱(곱하기 sqrt(2))</translation>
    </message>
    <message>
        <source> (gain %1)</source>
        <translation>(dlemr %1)</translation>
    </message>
</context>
<context>
    <name>FontParamField</name>
    <message>
        <source>Style:</source>
        <translation>스타일:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>크기:</translation>
    </message>
</context>
<context>
    <name>FrameNavigator</name>
    <message>
        <source>Previous Frame</source>
        <translation>이전 프레임</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>다음 프레임</translation>
    </message>
</context>
<context>
    <name>FunctionExpressionSegmentPage</name>
    <message>
        <source>Unit:</source>
        <translation>단위:</translation>
    </message>
    <message>
        <source>Expression:</source>
        <translation>표현:</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>보간 정의에는 원형 참조가 있음.</translation>
    </message>
</context>
<context>
    <name>FunctionPanel</name>
    <message>
        <source>Function Curves</source>
        <translation>함수 곡선</translation>
    </message>
    <message>
        <source>Link Handles</source>
        <translation>핸들 연결</translation>
    </message>
    <message>
        <source>Unlink Handles</source>
        <translation>핸들연결 해제</translation>
    </message>
    <message>
        <source>Reset Handles</source>
        <translation>핸들 재설정</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>키 설정</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>사이클 활성화</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>사이클 비활성화</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>선행 보간</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>속도가속/속도감속 중간값</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>서서히 멈춤/서서히 시작 보간</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>서서히 멈춤/서서히 시작(%)보간</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>지수 보간</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>표현 보간</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>표현 보간</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>상수 보간</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>비슷한 모양 보간</translation>
    </message>
    <message>
        <source>Fit Selection</source>
        <translation>선택 맞춤</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation>맞춤</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation>1단계</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation>2단계</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation>3단계</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation>4단계</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>부드러운</translation>
    </message>
    <message>
        <source>Frame Based</source>
        <translation>프레임 기반</translation>
    </message>
    <message>
        <source>Curve Shape</source>
        <translation>곡선 모양</translation>
    </message>
</context>
<context>
    <name>FunctionSegmentViewer</name>
    <message>
        <source>Linear</source>
        <translation>선형</translation>
    </message>
    <message>
        <source>Speed In / Speed Out</source>
        <translation>속도가속/속도감속</translation>
    </message>
    <message>
        <source>Ease In / Ease Out</source>
        <translation>서서히 멈춤/서서히 시작</translation>
    </message>
    <message>
        <source>Ease In / Ease Out %</source>
        <translation>서서히 멈춤/서서히 시작 %</translation>
    </message>
    <message>
        <source>Exponential</source>
        <translation>지수</translation>
    </message>
    <message>
        <source>Expression</source>
        <translation>표현식</translation>
    </message>
    <message>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <source>Constant</source>
        <translation>일정한</translation>
    </message>
    <message>
        <source>Similar Shape</source>
        <translation>유사한 모양</translation>
    </message>
    <message>
        <source>Interpolation:</source>
        <translation>보간:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>From</source>
        <translation>부터</translation>
    </message>
    <message>
        <source>To</source>
        <translation>로</translation>
    </message>
    <message>
        <source>Step</source>
        <translation>단계</translation>
    </message>
    <message>
        <source>&lt; </source>
        <translation></translation>
    </message>
    <message>
        <source> &gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>속도</translation>
    </message>
    <message>
        <source>Ease</source>
        <translation>용이성</translation>
    </message>
    <message>
        <source>Ease%</source>
        <translation>용이성%</translation>
    </message>
    <message>
        <source>Expo</source>
        <translation>지수간격</translation>
    </message>
    <message>
        <source>Expr</source>
        <translation></translation>
    </message>
    <message>
        <source>Const</source>
        <translation>콘스트</translation>
    </message>
    <message>
        <source>Similar</source>
        <translation>유사(비슷)</translation>
    </message>
    <message>
        <source>????</source>
        <translation></translation>
    </message>
    <message>
        <source>Link/Unlink Handles</source>
        <translation>링크/링크 해제 핸들</translation>
    </message>
</context>
<context>
    <name>FunctionSelection</name>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>보간 정의에는 원형 참조가 있음.</translation>
    </message>
</context>
<context>
    <name>FunctionSheet</name>
    <message>
        <source>Function Editor</source>
        <translation>기능 편집기</translation>
    </message>
</context>
<context>
    <name>FunctionSheetButtonArea</name>
    <message>
        <source>Toggle synchronizing zoom with xsheet</source>
        <translation>xsheet와 확대/축소 동기화 전환</translation>
    </message>
</context>
<context>
    <name>FunctionSheetCellViewer</name>
    <message>
        <source>Delete Key</source>
        <translation>키 삭제</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>키 설정</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>선행 보간</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>속도가속/속도감속 중간값</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>서서히 멈춤/서서히 시작 보간</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>서서히 멈춤/서서히 시작(%)보간</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>지수 보간</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>표현 보간</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>파일 보간</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>상수 보간</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation>1단계</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation>2단계</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation>3단계</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation>4단계</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>사이클 활성화</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>사이클 비활성화</translation>
    </message>
    <message>
        <source>Show Inbetween Values</source>
        <translation>중간 값 표시</translation>
    </message>
    <message>
        <source>Hide Inbetween Values</source>
        <translation>값 사이 숨기기</translation>
    </message>
    <message>
        <source>Change Interpolation</source>
        <translation>보간 변경</translation>
    </message>
    <message>
        <source>Change Step</source>
        <translation>단계 변경</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>비슷한 모양 보간</translation>
    </message>
</context>
<context>
    <name>FunctionSheetColumnHeadViewer</name>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation>이 매개변수의 일부 키가 표현식에서 원래 참조를 잃습니다.
키프레임을 수동으로 변경하면 경고가 지워집니다.</translation>
    </message>
</context>
<context>
    <name>FunctionToolbar</name>
    <message>
        <source>Value</source>
        <translation>값</translation>
    </message>
    <message>
        <source>&amp;Open Function Curve Editor</source>
        <translation>함수 곡선 편집기 열기(&amp;O)</translation>
    </message>
</context>
<context>
    <name>FunctionTreeModel</name>
    <message>
        <source>Stage</source>
        <translation>스테이지</translation>
    </message>
    <message>
        <source>FX</source>
        <translation></translation>
    </message>
    <message>
        <source>Plastic Skeleton</source>
        <translation>플라스틱 골격</translation>
    </message>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation>이 매개변수의 일부 키가 표현식에서 원래 참조를 잃습니다.
키프레임을 수동으로 변경하면 경고가 지워집니다.</translation>
    </message>
</context>
<context>
    <name>FunctionTreeView</name>
    <message>
        <source>Table</source>
        <translation>테이블</translation>
    </message>
    <message>
        <source>Save Curve</source>
        <translation>곡선 저장</translation>
    </message>
    <message>
        <source>Load Curve</source>
        <translation>곡선 가져오기</translation>
    </message>
    <message>
        <source>Export Data</source>
        <translation>데이터 내보내기</translation>
    </message>
    <message>
        <source>Show Animated Only</source>
        <translation>애니메이션만 표시</translation>
    </message>
    <message>
        <source>Show All</source>
        <translation>모두 표시</translation>
    </message>
    <message>
        <source>Hide Selected</source>
        <translation>선택한 항목 숨기기</translation>
    </message>
</context>
<context>
    <name>FxColumnPainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>X시트에서 연결해제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>X시트 연결(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>붙여넣기 추가(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>미리보기(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Uncache Fx</source>
        <translation>Fx 언캐시(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>Fx 캐시(&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxOutputPainter</name>
    <message>
        <source>Output</source>
        <translation>출력</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>활성화(&amp;A)</translation>
    </message>
</context>
<context>
    <name>FxPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>개방형 그룹(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Paste Replace</source>
        <translation>붙여넣기 교체(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>붙여넣기 추가(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>X시트에서 연결해제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>X시트 연결(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Create Linked FX</source>
        <translation>연결된 Fx 만들기(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Unlink</source>
        <translation>언링크(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Make Macro FX</source>
        <translation>매크로 Fx 만들기(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Explode Macro FX</source>
        <translation>매크로 Fx 분해(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Open Macro FX</source>
        <translation>Fx 매크로 열기(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Save As Preset...</source>
        <translation>사진 설정으로 저장(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>미리보기(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Uncache FX</source>
        <translation>Fx 언캐시(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>Fx 캐시(&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxPalettePainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>X시트에서 연결해제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>X시트 연결(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>미리보기(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxPassThroughPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation>붙여넣기 추가(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>미리보기(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxSchematicLink</name>
    <message>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Paste Insert</source>
        <translation>붙여넣기(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxSchematicOutputNode</name>
    <message>
        <source>Output</source>
        <translation>출력</translation>
    </message>
</context>
<context>
    <name>FxSchematicPassThroughNode</name>
    <message>
        <source> (Pass Through)</source>
        <translation> (통과)</translation>
    </message>
</context>
<context>
    <name>FxSchematicPort</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>X시트에서 연결해제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>X시트 연결(&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxSchematicScene</name>
    <message>
        <source>Cannot Paste Insert a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>연결되지 않은 Fx 노드의 선택 항목을 붙여넣을 수 없음.
붙여넣을 선택 항목을 복사하거나 잘라내기 전에 Fx 노드 및 관련 링크선택하세요.</translation>
    </message>
    <message>
        <source>Cannot Paste Add a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>연결되지 않은 Fx 노드의 선택 항목을 붙여넣을 수 없음.
붙여넣을 선택 항목을 복사하거나 잘라내기 전에 Fx 노드 및 관련 링크선택하세요.</translation>
    </message>
    <message>
        <source>Cannot Paste Replace a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>연결되지 않은 Fx 노드의 선택 항목을 붙여넣을 수가 없음.
붙여넣을 선택항목을 복사하거나 잘라내기 전에 Fx 노드 및 관련 링크 선택하세요.</translation>
    </message>
</context>
<context>
    <name>FxSchematicXSheetNode</name>
    <message>
        <source>XSheet</source>
        <translation>X-시트</translation>
    </message>
</context>
<context>
    <name>FxSettings</name>
    <message>
        <source>&amp;Camera Preview</source>
        <translation>카메라 미리보기(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>미리보기(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>흰색 배경(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>검은 배경(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>체크무늬 배경(&amp;C)</translation>
    </message>
    <message>
        <source>Fx Settings</source>
        <translation>Fx 설정</translation>
    </message>
    <message>
        <source> : </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FxXSheetPainter</name>
    <message>
        <source>XSheet</source>
        <translation>X-시트</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>붙여넣기 추가(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>미리보기(&amp;P)</translation>
    </message>
</context>
<context>
    <name>GroupPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>개방형 그룹(&amp;O)</translation>
    </message>
</context>
<context>
    <name>Histogram</name>
    <message>
        <source>Logarithmic Scale</source>
        <translation>로그함수 스케일</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>값</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation></translation>
    </message>
    <message>
        <source>Red</source>
        <translation>빨강</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>녹색</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>파랑</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>알파</translation>
    </message>
</context>
<context>
    <name>InfoViewer</name>
    <message>
        <source>File Info</source>
        <translation>파일 정보</translation>
    </message>
</context>
<context>
    <name>KeyframeNavigator</name>
    <message>
        <source>Previous Key</source>
        <translation>이전 키</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>키 설정</translation>
    </message>
    <message>
        <source>Next Key</source>
        <translation>새로운 키</translation>
    </message>
</context>
<context>
    <name>LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation>파일 이름에는 다음 문자 중 어느 것도 포함될 수 없음: /\:*?&quot;&lt;&gt;|.</translation>
    </message>
</context>
<context>
    <name>MyPaintBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation>일반 색상</translation>
    </message>
</context>
<context>
    <name>NewWordDialog</name>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Enter new word</source>
        <translation>새로운 단어 입력</translation>
    </message>
</context>
<context>
    <name>PageViewer</name>
    <message>
        <source>- No Styles -</source>
        <translation>- 스타일 없음 -</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation>이름 편집기</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation>새로운 스타일</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>새로운 페이지</translation>
    </message>
</context>
<context>
    <name>PaletteViewer</name>
    <message>
        <source>&amp;Save Palette As</source>
        <translation>다른 이름으로 팔레트 저장(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Save Palette</source>
        <translation>팔레트 저장(&amp;S)</translation>
    </message>
    <message>
        <source>Lock Palette</source>
        <translation>팔레트 잠금</translation>
    </message>
    <message>
        <source>&amp;Lock Palette</source>
        <translation>팔레트 잠금(&amp;L)</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails View</source>
        <translation>축소판 보기(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Medium Thumbnails View</source>
        <translation>중간 축소판 보기(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Large Thumbnails View</source>
        <translation>큰 축소판 보기(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;List View</source>
        <translation>목록 보기(&amp;L)</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation>스타일 이름</translation>
    </message>
    <message>
        <source>StudioPalette Name</source>
        <translation>스튜디오 팔레트 이름</translation>
    </message>
    <message>
        <source>Both Names</source>
        <translation>양쪽 이름</translation>
    </message>
    <message>
        <source>&amp;New Page</source>
        <translation>새로운 페이지(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Style</source>
        <translation>새로운 스타일(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Move Palette</source>
        <translation>팔레트 이동(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Palette Gizmo</source>
        <translation>팔레트 기즈모(&amp;P)</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>새로운 페이지</translation>
    </message>
    <message>
        <source>Delete Page</source>
        <translation>페이지 삭제</translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation>덮어쓰기</translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation>덮어쓰지 마세요</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>팔레트</translation>
    </message>
    <message>
        <source>Level Palette: </source>
        <translation>팔레트 레벨:</translation>
    </message>
    <message>
        <source>Cleanup Palette</source>
        <translation>팔레트 정리</translation>
    </message>
    <message>
        <source>Studio Palette</source>
        <translation>스튜디오 팔레트</translation>
    </message>
    <message>
        <source>     (Color Model: </source>
        <translation> (색상 모델: </translation>
    </message>
    <message>
        <source>)</source>
        <translation></translation>
    </message>
    <message>
        <source>Hide New Style Button</source>
        <translation>새 스타일 버튼 숨기기</translation>
    </message>
    <message>
        <source>Show New Style Button</source>
        <translation>새 스타일 버튼 표시</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>팔레트를 저장하지 못했습니다.</translation>
    </message>
    <message>
        <source>Set Toolbar Below Styles</source>
        <translation>스타일 아래에 도구 모음 설정</translation>
    </message>
    <message>
        <source>Set Toolbar Above Styles</source>
        <translation>스타일 위에 도구 모음 설정</translation>
    </message>
    <message>
        <source>Auto Adjust Panel Width</source>
        <translation>패널 너비자동조정</translation>
    </message>
    <message>
        <source>Visible Toolbar Buttons</source>
        <translation>표시되는 도구 모음 버튼</translation>
    </message>
    <message>
        <source>KeyFrame</source>
        <translation>키 프레임</translation>
    </message>
    <message>
        <source>New Style/Page</source>
        <translation>새로운 스타일/페이지</translation>
    </message>
    <message>
        <source>Palette Gizmo</source>
        <translation>팔레트 기즈모</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation>이름 편집기</translation>
    </message>
</context>
<context>
    <name>PaletteViewerGUI::PageViewer</name>
    <message>
        <source>- No Styles -</source>
        <translation>- 스타일 없음 -</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation>이름 편집기</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation>새로운 스타일</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>새로운 페이지</translation>
    </message>
    <message>
        <source> + </source>
        <translation> + </translation>
    </message>
</context>
<context>
    <name>PalettesScanPopup</name>
    <message>
        <source>Search for Palettes</source>
        <translation>팔레트 검색</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>&lt;files&gt;</source>
        <translation>&lt;파일&gt;</translation>
    </message>
    <message>
        <source>Failed to import palette.</source>
        <translation>팔레트를 가져오지 못했습니다.</translation>
    </message>
</context>
<context>
    <name>ParamViewer</name>
    <message>
        <source>Swatch Viewer</source>
        <translation>견본 뷰어</translation>
    </message>
</context>
<context>
    <name>ParamsPageSet</name>
    <message>
        <source>Fx Help</source>
        <translation>Fx 도움말</translation>
    </message>
    <message>
        <source>View help page</source>
        <translation>도움말 페이지 보기</translation>
    </message>
    <message>
        <source>This Fx does not support rendering in floating point channel width (32bit).
The output pixel values from this fx will be clamped to 0.0 - 1.0
and tone may be slightly discretized.</source>
        <translation>이 Fx는 부동 소수점 채널 너비(32비트)로 랜더링을 지원하지 않습니다.
이 Fx의 출력 픽셀 값은 0.0 ~ 1.0으로 클램핑되며, 톤이 약간 불연속화될 수 있습니다.</translation>
    </message>
</context>
<context>
    <name>PegbarPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>중심 재설정(&amp;R)</translation>
    </message>
</context>
<context>
    <name>PlaneViewer</name>
    <message>
        <source>Reset View</source>
        <translation>보기 재설정</translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation>창에 맞춤</translation>
    </message>
</context>
<context>
    <name>PointParamField</name>
    <message>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <source>Y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <source>OpenToonz</source>
        <translation>오픈툰즈</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deleting &quot;%1&quot;.
Are you sure?</source>
        <translation>&quot;%1&quot;을 삭제합니다. 확실합니까?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>It is not possible to delete the style #</source>
        <translation># 스타일을 삭제할 수 없음</translation>
    </message>
    <message>
        <source>Paste Style  in Palette : %1</source>
        <translation>팔레트의 붙여넣기 스타일:%1</translation>
    </message>
    <message>
        <source>Delete Style  from Palette : %1</source>
        <translation>팔레트에서 스타일 삭제: %1</translation>
    </message>
    <message>
        <source>Cut Style  from Palette : %1</source>
        <translation>팔레트에서 잘라낸 스타일: %1</translation>
    </message>
    <message>
        <source>It is not possible to delete styles #0 and #1.</source>
        <translation>스타일 #0 과 #1을 삭제할 수 없음.</translation>
    </message>
    <message>
        <source>Can&apos;t paste styles there</source>
        <translation>스타일을 붙여넣을 수 없음</translation>
    </message>
    <message>
        <source>  to Palette : %1</source>
        <translation>팔레트: %1</translation>
    </message>
    <message>
        <source>Paste Color &amp;&amp; Name%1</source>
        <translation>색상 &amp;&amp;이름붙여넣기 %1</translation>
    </message>
    <message>
        <source>Paste Name%1</source>
        <translation>이름 붙여넣기 %1</translation>
    </message>
    <message>
        <source>Paste Color%1</source>
        <translation>색상 붙여넣기 %1</translation>
    </message>
    <message>
        <source>Paste%1</source>
        <translation>%1 붙여넣기</translation>
    </message>
    <message>
        <source>Can&apos;t modify color #0</source>
        <translation>색상 수정할 수 없음</translation>
    </message>
    <message>
        <source>There are more cut/copied styles than selected. Paste anyway (adding styles)?</source>
        <translation>선택한 스타일보다 컷/복사 스타일이 더많음. 붙여넣기(스타일추가)?</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Blend Colors  in Palette : %1</source>
        <translation>팔레트의 혼합색상: %1</translation>
    </message>
    <message>
        <source>Toggle Link  in Palette : %1</source>
        <translation>팔레트에서 링크전환: %1</translation>
    </message>
    <message>
        <source>Remove Reference  in Palette : %1</source>
        <translation>팔레트에서 참조 제거: %1</translation>
    </message>
    <message>
        <source>Get Color from Studio Palette</source>
        <translation>스튜디오 팔레트에서 색상 가져오기</translation>
    </message>
    <message>
        <source>Paste Object  </source>
        <translation>개체 붙여넣기</translation>
    </message>
    <message>
        <source>Copy Keyframe</source>
        <translation>키 프레임 복사</translation>
    </message>
    <message>
        <source>Paste Keyframe  at Frame : %1</source>
        <translation>프레임에 키 프레임 붙여넣기: %1</translation>
    </message>
    <message>
        <source>Delete Keyframe</source>
        <translation>키 프레임 삭제</translation>
    </message>
    <message>
        <source>Move Keyframe</source>
        <translation>키 프레임 이동</translation>
    </message>
    <message>
        <source>Save Motion Path</source>
        <translation>이동경로 저장</translation>
    </message>
    <message>
        <source>Motion Path files (*.mpath)</source>
        <translation>모션경로 파일(*.mpath)</translation>
    </message>
    <message>
        <source>It is not possible to save the motion path.</source>
        <translation>모션 경로를 저장할 수 없음.</translation>
    </message>
    <message>
        <source>Load Motion Path</source>
        <translation>이동경로 가져오기</translation>
    </message>
    <message>
        <source>It is not possible to load the motion path.</source>
        <translation>모션 경로를 가져오기 할 수 없음.</translation>
    </message>
    <message>
        <source>Stage Schematic</source>
        <translation>도식단계</translation>
    </message>
    <message>
        <source>FX Schematic</source>
        <translation>Fx 도식</translation>
    </message>
    <message>
        <source>Change Style   Palette : %1  Style#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</source>
        <translation>스타일 팔레트 변경: %1 스타일#%2 [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>네</translation>
    </message>
    <message>
        <source>No</source>
        <translation>아니요</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>교체</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1</source>
        <translation>Fx 매개변수 수정: %1</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 -&gt; %3</source>
        <translation>Fx 매개변수 수정: %1 : %2 -&gt; %3</translation>
    </message>
    <message>
        <source>Modify Fx Param : </source>
        <translation>Fx 매개변수 수정: </translation>
    </message>
    <message>
        <source>ON : %1</source>
        <translation>켬 : %1</translation>
    </message>
    <message>
        <source>OFF : %1</source>
        <translation>끔 : %1</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Key</source>
        <translation>Fx 매개변수: %1 :%2 키</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>추가</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>제거</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Point</source>
        <translation>Fx 매개변수 수정: %1 %2 포인트</translation>
    </message>
    <message>
        <source>%1 : Linear ON</source>
        <translation>%1 : 선형 켬</translation>
    </message>
    <message>
        <source>%1 : Linear OFF</source>
        <translation>%1: 선형 끔</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>팔레트</translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation>덮어쓰기</translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation>덮어쓰지 마세요</translation>
    </message>
    <message>
        <source>It is not possible to assign a shortcut with modifiers to the visualization commands.</source>
        <translation>시각화 명령에 수식어가 있는 바로 가기를 할당 할 수 없음.</translation>
    </message>
    <message>
        <source>Fullpath:     </source>
        <translation>전체 경로: </translation>
    </message>
    <message>
        <source>File Type:    </source>
        <translation>파일 유형: </translation>
    </message>
    <message>
        <source>Frames:       </source>
        <translation>프레임: </translation>
    </message>
    <message>
        <source>Owner:        </source>
        <translation>소유자: </translation>
    </message>
    <message>
        <source>Size:         </source>
        <translation>크기: </translation>
    </message>
    <message>
        <source>Created:      </source>
        <translation>생성: </translation>
    </message>
    <message>
        <source>Modified:     </source>
        <translation>수정: </translation>
    </message>
    <message>
        <source>Last Access:  </source>
        <translation>마지막 액세스: </translation>
    </message>
    <message>
        <source>Image Size:   </source>
        <translation>이미지 사이즈: </translation>
    </message>
    <message>
        <source>SaveBox:      </source>
        <translation>저장 상자: </translation>
    </message>
    <message>
        <source>Bits/Sample:  </source>
        <translation>비트/샘플: </translation>
    </message>
    <message>
        <source>Sample/Pixel: </source>
        <translation>샘플/픽셀: </translation>
    </message>
    <message>
        <source>Dpi:          </source>
        <translation>DPI: </translation>
    </message>
    <message>
        <source>Orientation:  </source>
        <translation>방향: </translation>
    </message>
    <message>
        <source>Compression:  </source>
        <translation>압축: </translation>
    </message>
    <message>
        <source>Quality:      </source>
        <translation>품질: </translation>
    </message>
    <message>
        <source>Smoothing:    </source>
        <translation>평활: </translation>
    </message>
    <message>
        <source>Codec:        </source>
        <translation>코덱: </translation>
    </message>
    <message>
        <source>Alpha Channel:</source>
        <translation>알파 채널:</translation>
    </message>
    <message>
        <source>Byte Ordering:</source>
        <translation>바이트 순서:</translation>
    </message>
    <message>
        <source>H Pos:</source>
        <translation>수평 위치:</translation>
    </message>
    <message>
        <source>Palette Pages:</source>
        <translation>팔레트 페이지:</translation>
    </message>
    <message>
        <source>Palette Styles:</source>
        <translation>팔레트 스타일:</translation>
    </message>
    <message>
        <source>Camera Size:      </source>
        <translation>카메라 사이즈: </translation>
    </message>
    <message>
        <source>Camera Dpi:       </source>
        <translation>카메라 DPI: </translation>
    </message>
    <message>
        <source>Number of Frames: </source>
        <translation>프레임 수: </translation>
    </message>
    <message>
        <source>Number of Levels: </source>
        <translation>레벨 수: </translation>
    </message>
    <message>
        <source>Output Path:      </source>
        <translation>출력 경로: </translation>
    </message>
    <message>
        <source>Endianness:      </source>
        <translation>엔디언: </translation>
    </message>
    <message>
        <source>Length:       </source>
        <translation>길이: </translation>
    </message>
    <message>
        <source>Channels: </source>
        <translation>채널: </translation>
    </message>
    <message>
        <source>Sample Rate: </source>
        <translation>샘플 속도: </translation>
    </message>
    <message>
        <source>Sample Size:      </source>
        <translation>샘플 크기: </translation>
    </message>
    <message>
        <source>The file %1 does not exist.</source>
        <translation>%1 파일이 없음.</translation>
    </message>
    <message>
        <source>It is not possible to find the %1 level.</source>
        <translation>레벨 %1을 찾을 수 없음.</translation>
    </message>
    <message>
        <source>There was an error copying %1</source>
        <translation>%1를 복사하는 중 오류 발생</translation>
    </message>
    <message>
        <source>It is not possible to find the level %1</source>
        <translation>%1 레벨을 찾을 수 없음</translation>
    </message>
    <message>
        <source>Cannot premultiply the selected file.</source>
        <translation>선택한 파일을 미리 확인 할 수 없음.</translation>
    </message>
    <message>
        <source>Cannot premultiply a vector-based level.</source>
        <translation>벡터 기반 레벨을 미리 설정할 수 없음.</translation>
    </message>
    <message>
        <source>Level %1 premultiplied.</source>
        <translation>레벨 %1에 미리 제공됨.</translation>
    </message>
    <message>
        <source>Frame %1 : conversion failed!</source>
        <translation>프레임 %1: 변환실패!</translation>
    </message>
    <message>
        <source>The source image seems not suitable for this kind of conversion</source>
        <translation>소스 이미지는 이러한 종류의 변환에 적합하지 않는 것으로 보임</translation>
    </message>
    <message>
        <source>The file name cannot be empty or contain any of the following characters: (new line) \ / : * ? &quot; |</source>
        <translation>파일 이름은 비어 있거나 다음 문자중 하나를 포함할 수 없음: (새 줄) ) \ / : * ? : ㅣ</translation>
    </message>
    <message>
        <source>OpenToonz 1.3</source>
        <translation>오픈툰즈 1.3</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>질문</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Styles you are going to delete are used to paint lines and areas in the animation level.
</source>
        <translation>삭제할 스타일은 애니메이션 레벨의 선과 영역을 그리는데 사용됨.</translation>
    </message>
    <message>
        <source>How do you want to proceed?</source>
        <translation>어떻게 진행하시겠습니까?</translation>
    </message>
    <message>
        <source>Delete Styles Only</source>
        <translation>스타일만 삭제</translation>
    </message>
    <message>
        <source>Delete Styles, Lines and Areas</source>
        <translation>스타일, 선 및 영역 삭제</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Deletion of Lines and Areas from raster-based levels is not undoable.
Are you sure?</source>
        <translation>래스터 기반 레벨에서 선 및 영역을 삭제하는 것은 취소 할 수 없음.
확실합니까?</translation>
    </message>
    <message>
        <source>Failed to compile m_textureShader.vert.</source>
        <comment>gl</comment>
        <translation>m_textureShader.vert 컴파일하지 못함.</translation>
    </message>
    <message>
        <source>Failed to compile m_shader.frag.</source>
        <comment>gl</comment>
        <translation>m_shader.frag 컴파일 하지 못함.</translation>
    </message>
    <message>
        <source>Failed to add m_shader.vert.</source>
        <comment>gl</comment>
        <translation>m_shader.vert 추가하지 못함.</translation>
    </message>
    <message>
        <source>Failed to add m_shader.frag.</source>
        <comment>gl</comment>
        <translation>m_shader.frag 추가하지 못함.</translation>
    </message>
    <message>
        <source>Failed to link simple shader: %1</source>
        <comment>gl</comment>
        <translation>간단한 쉐이더를 연결하지 목함: %1</translation>
    </message>
    <message>
        <source>Failed to get attribute location of %1</source>
        <comment>gl</comment>
        <translation>%1의 속성 위치를 가져오지 못함</translation>
    </message>
    <message>
        <source>Failed to get uniform location of %1</source>
        <comment>gl</comment>
        <translation>%1의 동일한 위치를 가져오지 못함</translation>
    </message>
    <message>
        <source>Failed to Open 3DLUT File.</source>
        <translation>3D LUT 파일을 열지못함.</translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
It should start with &quot;3DMESH&quot; keyword.</source>
        <translation>3D LUT 파일을 가져오지 못함.
3D 메쉬; 키워드로 시작해야함. </translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;</source>
        <translation>3DLUT 파일을 오드하지 못함.
두번째 라인은 메쉬 여야함.[입력비트깊이] [출력 비트 깊이]</translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.</source>
        <translation>3DLUT 파일을 오드 하지못함.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Current Frame: </source>
        <translation>현재 프레임: </translation>
    </message>
    <message>
        <source>File History</source>
        <translation>파일 히스토리</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>VectorBrushStyleChooserPage</comment>
        <translation>일반 색상</translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation>사용자 지정 텍스처</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>MyPaintBrushStyleChooserPage</comment>
        <translation>일반 색상</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>SpecialStyleChooserPage</comment>
        <translation>일반 색상</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 Key : %2  Frame %3</source>
        <translation>Fx 매개변수 수정: %1 키 : %2 프레임 %3</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>That is a reserved file name and cannot be used.</source>
        <translation>이것은 예약 된 파일 이름이며 사용할 수 없습니다.</translation>
    </message>
    <message>
        <source>There are no unused styles.</source>
        <translation>사용하지 않는 스타일이 없습니다.</translation>
    </message>
    <message>
        <source>and %1 more styles.</source>
        <translation>스타일이 %1개 더 있습니다.</translation>
    </message>
    <message>
        <source>Erasing unused styles with following indices. Are you sure?

%1</source>
        <translation>다음 지수로 사용하지 않는 스타일을 지 웁니다. 확실합니까?

%1</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Click &amp; Drag Palette into Studio Palette</source>
        <translation>팔레트를 클릭하여 스튜디오 팔레트로 끌어오기</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>TextureStyleChooserPage</comment>
        <translation>일반 색상</translation>
    </message>
    <message>
        <source>Sample Type: </source>
        <translation>샘플 유형:</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
</context>
<context>
    <name>RadioButtonDialog</name>
    <message>
        <source>OpenToonz</source>
        <translation>오픈툰즈</translation>
    </message>
</context>
<context>
    <name>RgbLinkButtons</name>
    <message>
        <source>Copy RGB : %1 &gt; %2</source>
        <translation>RGB 복사: %1 &gt; %2</translation>
    </message>
    <message>
        <source>Swap %1 and %2</source>
        <translation>스완%1과 %2</translation>
    </message>
</context>
<context>
    <name>SchematicName</name>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cu&amp;t</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;복사</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;붙여넣기</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;모두선택</translation>
    </message>
</context>
<context>
    <name>SchematicViewer</name>
    <message>
        <source>&amp;Fit to Window</source>
        <translation>창에 맞춤(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Focus on Current</source>
        <translation>현재에 초점(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Reorder Nodes</source>
        <translation>노드 재정렬(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Reset Size</source>
        <translation>크기 재설정(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Minimize Nodes</source>
        <translation>노드 최소화(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Maximize Nodes</source>
        <translation>노드 최대화(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>새로운 페그바(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>새로운 카메라(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>새로운 동작 경로(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Swtich output port display mode</source>
        <translation>스위치 출력 포트 표시모드(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Toggle node icons</source>
        <translation>노드 아이콘 전환(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Selection Mode</source>
        <translation>선택모드(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Zoom Mode</source>
        <translation>확대 모드(&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Hand Mode</source>
        <translation>핸드 모드(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Switch output port display mode</source>
        <translation>&amp;출력 포트 표시 모드 전환</translation>
    </message>
</context>
<context>
    <name>SchematicWindowEditor</name>
    <message>
        <source>&amp;Close Editor</source>
        <translation>편집기 닫기(&amp;C)</translation>
    </message>
</context>
<context>
    <name>SeeThroughWindowPopup</name>
    <message>
        <source>See Through Mode (Main Window)</source>
        <translation>투시모드(기본창)</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>불투명도</translation>
    </message>
    <message>
        <source>Quickly toggle main window semi-transparency and full opacity.</source>
        <translation>기본 창 반투명도와 전체 불투명도를 빠르게 전환할 수 있습니다.</translation>
    </message>
    <message>
        <source>Hold ALT while clicking to use full transparency instead.</source>
        <translation>전체 투명도를 사용하려면 클릭하는 동안 Alt 키를 누르고 있습니다.</translation>
    </message>
    <message>
        <source>When slider is at 100% it acts as ALT is held.</source>
        <translation>슬라이더를 100%로 설정하면 ALT를 누른 상태로 작동합니다.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Reset to default</source>
        <translation>기본값으로 재설정</translation>
    </message>
</context>
<context>
    <name>SimilarShapeSegmentPage</name>
    <message>
        <source>Reference Curve:</source>
        <translation>기준 곡선:</translation>
    </message>
    <message>
        <source>Frame Offset:</source>
        <translation>프레임 오프셋:</translation>
    </message>
    <message>
        <source>There is a syntax error in the definition of the interpolation.</source>
        <translation>보간법의 정의에는 구문 오류가 있음.</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>보간 정의에는 원형 참조가 있음.</translation>
    </message>
</context>
<context>
    <name>SpecialStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation>일반 색상</translation>
    </message>
</context>
<context>
    <name>SpeedInOutSegmentPage</name>
    <message>
        <source>First Speed:</source>
        <translation>첫번째 속도:</translation>
    </message>
    <message>
        <source>Handle:</source>
        <translation>핸들:</translation>
    </message>
    <message>
        <source>/</source>
        <translation></translation>
    </message>
    <message>
        <source>Last Speed:</source>
        <translation>마지막 속도:</translation>
    </message>
    <message>
        <source>---</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SplinePainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>삭제(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Save Motion Path...</source>
        <translation>이동경로 저장(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Load Motion Path...</source>
        <translation>이동경로 가져오기(&amp;L)...</translation>
    </message>
</context>
<context>
    <name>StageSchematicNode</name>
    <message>
        <source>Toggle Autorotate Along Motion Path</source>
        <translation>이동 경로를 따라 자동 조정</translation>
    </message>
    <message>
        <source>Toggle Link Motion Path to Control Points</source>
        <translation>링크 이동 경로를 컨트롤 포인트로 전환</translation>
    </message>
</context>
<context>
    <name>StageSchematicScene</name>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>새로운 페그바(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>새로운 동작 경로(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>새로운 카메라(&amp;N)</translation>
    </message>
</context>
<context>
    <name>StudioPaletteTreeViewer</name>
    <message>
        <source>This folder is not empty. Delete anyway?</source>
        <translation>이 폴더는 비어 있지 않음. 삭제하겠습니까?</translation>
    </message>
    <message>
        <source>New Palette</source>
        <translation>새로운 팔레트</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>새 폴더</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>폴더 삭제</translation>
    </message>
    <message>
        <source>Load into Current Palette</source>
        <translation>현재 팔레트로 가져오기</translation>
    </message>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>이 팔레트에 현재 레벨 조정</translation>
    </message>
    <message>
        <source>Merge to Current Palette</source>
        <translation>현재 팔레트로 병합</translation>
    </message>
    <message>
        <source>Replace with Current Palette</source>
        <translation>현재 팔레트로 교체</translation>
    </message>
    <message>
        <source>Delete Palette</source>
        <translation>팔레트 삭제</translation>
    </message>
    <message>
        <source>Convert to Studio Palette and Overwrite</source>
        <translation>스튜디오 팔레트로 변환 및 덮어쓰기</translation>
    </message>
    <message>
        <source>Search for Palettes</source>
        <translation>팔레트 검색</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>the palette &quot;%1&quot;</source>
        <translation>팔레트 %1</translation>
    </message>
    <message>
        <source>the selected palettes</source>
        <translation>선택된 팔레트</translation>
    </message>
    <message>
        <source>Move %1 to &quot;%2&quot;. Are you sure ?</source>
        <translation>%1을 %2로 이동하겠습니까?</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>이동</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>The current palette %1
in the studio palette has been modified. Do you want to save your changes?</source>
        <translation>현재 팔레트 %1 스튜디오 팔레트에서 수정 되었음. 변경 사항을 저장 하겠습니까?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Convert %1 to Studio Palette and Overwrite. 
Are you sure ?</source>
        <translation>%1을 스튜디오 팔레트로 변환하고 덮어쓰기 함. 확실합니까?</translation>
    </message>
    <message>
        <source>Convert</source>
        <translation>변환</translation>
    </message>
    <message>
        <source>Replacing all selected palettes with the palette &quot;%1&quot;. 
Are you sure ?</source>
        <translation>선택한 모든 팔레트를 팔레트 &quot;%1&quot;로 대체함. 확실합니까?</translation>
    </message>
    <message>
        <source>Replacing the palette &quot;%1&quot; with the palette &quot;%2&quot;. 
Are you sure ?</source>
        <translation>팔레트 &quot;%1&quot;을 팔레트 &quot;%2&quot;로 대체함. 확실합니까? </translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>교체</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>팔레트를 저장하지 못했습니다.</translation>
    </message>
</context>
<context>
    <name>StyleEditor</name>
    <message>
        <source>Generated</source>
        <translation>생성</translation>
    </message>
    <message>
        <source>Trail</source>
        <translation>트레일</translation>
    </message>
    <message>
        <source>Vector Brush</source>
        <translation>벡터 브러쉬</translation>
    </message>
    <message>
        <source>Show or hide parts of the Color Page.</source>
        <translation>색 페이지의 일부 표시 또는 숨기기.</translation>
    </message>
    <message>
        <source>Wheel</source>
        <translation>휠</translation>
    </message>
    <message>
        <source>HSV</source>
        <translation></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>알파</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation></translation>
    </message>
    <message>
        <source>Toggle orientation of the Color Page.</source>
        <translation>색상 페이지의 방향 전환.</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>자동</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Apply changes to current style</source>
        <translation>현재 스타일에 변경 사항적용</translation>
    </message>
    <message>
        <source>Automatically update style changes</source>
        <translation>스타일 변경 자동 업데이트</translation>
    </message>
    <message>
        <source>Return To Previous Style</source>
        <translation>이전 스타일로 돌아가기</translation>
    </message>
    <message>
        <source>Current Style</source>
        <translation>현재 스타일</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>색상</translation>
    </message>
    <message>
        <source>Texture</source>
        <translation>텍스처</translation>
    </message>
    <message>
        <source>Vector</source>
        <translation>벡터</translation>
    </message>
    <message>
        <source>Raster</source>
        <translation>래스터</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>No Style Selected</source>
        <translation>선택한 스타일 없음</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>팔레트</translation>
    </message>
    <message>
        <source>Style Editor - No Valid Style Selected</source>
        <translation>스타일 편집기 - 유효한 스타일이 선택되지 않음</translation>
    </message>
    <message>
        <source>[CLEANUP]  </source>
        <translation>[정리]</translation>
    </message>
    <message>
        <source>[STUDIO]  </source>
        <translation>[스튜디오]</translation>
    </message>
    <message>
        <source>[LEVEL]  </source>
        <translation>[레벨]</translation>
    </message>
    <message>
        <source>Cleanup </source>
        <translation>정리</translation>
    </message>
    <message>
        <source>Studio </source>
        <translation>스튜디오</translation>
    </message>
    <message>
        <source>Level </source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Hex</source>
        <translation>Hex</translation>
    </message>
    <message>
        <source>Relative colored + Triangle handle</source>
        <translation>상대적 색상 + 삼각형 핸들</translation>
    </message>
    <message>
        <source>Absolute colored + Line handle</source>
        <translation>절대 컬러 + 라인 핸들</translation>
    </message>
    <message>
        <source>Slider Appearance</source>
        <translation>슬라이더 외관</translation>
    </message>
    <message>
        <source>Toggle Orientation</source>
        <translation>방향 전환</translation>
    </message>
    <message>
        <source>Hex Color Names...</source>
        <translation>16진수 색상 이름...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translation>검색 삭제</translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::ColorChannelControl</name>
    <message>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <source>G</source>
        <translation></translation>
    </message>
    <message>
        <source>B</source>
        <translation></translation>
    </message>
    <message>
        <source>A</source>
        <translation></translation>
    </message>
    <message>
        <source>H</source>
        <translation>수평</translation>
    </message>
    <message>
        <source>S</source>
        <translation></translation>
    </message>
    <message>
        <source>V</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::SettingsPage</name>
    <message>
        <source>Autopaint for Lines</source>
        <translation>선 자동 페인트</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>기본값으로 재설정</translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::StyleChooserPage</name>
    <message>
        <source>Pin To Top</source>
        <translation>맨 위로 고정</translation>
    </message>
    <message>
        <source>Set Pins To Top</source>
        <translation>핀을 상단으로 설정</translation>
    </message>
    <message>
        <source>Clear Pins To Top</source>
        <translation>핀을 위로 지우기</translation>
    </message>
</context>
<context>
    <name>StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>현재</translation>
    </message>
</context>
<context>
    <name>StyleNameEditor</name>
    <message>
        <source>Name Editor</source>
        <translation>이름 편집기</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>네</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Apply and Next</source>
        <translation>적용 후 다음</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation>스타일 이름</translation>
    </message>
    <message>
        <source>Easy Inputs</source>
        <translation>쉬운 입력</translation>
    </message>
    <message>
        <source>Name Editor: # %1</source>
        <translation>이름 편집기: # %1</translation>
    </message>
</context>
<context>
    <name>SwatchViewer</name>
    <message>
        <source>Reset View</source>
        <translation>보기 재설정</translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation>창에 맞춤</translation>
    </message>
</context>
<context>
    <name>TMessageViewer</name>
    <message>
        <source>Display:  </source>
        <translation>표시:</translation>
    </message>
    <message>
        <source>Errors</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source> Clear </source>
        <translation>명확한</translation>
    </message>
</context>
<context>
    <name>TablePainter</name>
    <message>
        <source>Table</source>
        <translation>테이블</translation>
    </message>
    <message>
        <source>&amp;Reset Center</source>
        <translation>중심 재설정(&amp;R)</translation>
    </message>
</context>
<context>
    <name>ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation>채널:</translation>
    </message>
</context>
<context>
    <name>VectorBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation>일반 색상</translation>
    </message>
</context>
<context>
    <name>WordButton</name>
    <message>
        <source>Remove %1</source>
        <translation>%1 제거</translation>
    </message>
</context>
</TS>
